Learn R Programming

datarium (version 0.2.0)

AirPassengersDf: Air Passengers

Description

This dataset contains the number of monthly air passengers from 1949 to 1960. It is taken from the R datasets package and formatted into long data frame format.

Usage

data("AirPassengersDf")

Arguments

Format

A data frame with 144 rows and 2 columns.

Month

the month of the observation, as a Date (the first day of each month from January 1949 to December 1960).

Passengers

the monthly total of international airline passengers.

References

Box, G. E. P., Jenkins, G. M. and Reinsel, G. C. (1976) Time Series Analysis, Forecasting and Control. San Francisco: Holden-Day.

Examples

Run this code
data("AirPassengersDf")
head(AirPassengersDf)

# Monthly international airline passengers over time
plot(Passengers ~ Month, data = AirPassengersDf, type = "l")

Run the code above in your browser using DataLab