Learn R Programming

datarium (version 0.2.0)

marketing: Marketing Data Set

Description

A data frame containing the impact of three advertising medias (youtube, facebook and newspaper) on sales. Data are the advertising budget in thousands of dollars along with the sales (in thousands of units). The advertising experiment has been repeated 200 times. This is a simulated data.

It is the data set used in the Datanovia tutorial “Multiple Linear Regression in R: Several Predictors” (https://www.datanovia.com/learn/biostatistics/regression/multiple-linear-regression-in-r).

Usage

data("marketing")

Arguments

Format

A data frame with 200 rows and 4 columns.

youtube

the advertising budget spent on YouTube, in thousands of dollars.

facebook

the advertising budget spent on Facebook, in thousands of dollars.

newspaper

the advertising budget spent on newspaper, in thousands of dollars.

sales

the sales generated, in thousands of units.

See Also

Examples

Run this code
data(marketing)
res.lm <- lm(sales ~ youtube*facebook, data = marketing)
summary(res.lm)

Run the code above in your browser using DataLab