Learn R Programming

datarium (version 0.2.0)

taskachievment: Task Achievment Data for Cochran's Q Test

Description

Repeated measures nominal designs where 73 subjects are asked to perform 3 tasks. The outcome of each task is a dichotomous value, success or failure. Each row correspond to a participant (called "block" in the jargon). This a demo dataset for Cochran's Q test.

It is the data set used in the Datanovia tutorial “Cochran's Q Test in R: Compare Three or More Paired Proportions” (https://www.datanovia.com/learn/biostatistics/categorical/cochran-q-test-in-r).

Usage

data("taskachievment")

Arguments

Format

A data frame with 73 rows and 4 columns (stored as a tibble).

participant

participant identifier (1 to 73).

Task1

the outcome of task 1: 0 (failure) or 1 (success).

Task2

the outcome of task 2: 0 (failure) or 1 (success).

Task3

the outcome of task 3: 0 (failure) or 1 (success).

See Also

Examples

Run this code
data(taskachievment)
head(taskachievment)

# Proportion of success for each task
colMeans(taskachievment[, c("Task1", "Task2", "Task3")])

Run the code above in your browser using DataLab