Learn R Programming

datarium (version 0.2.0)

jobsatisfaction: Job Satisfaction Data for Two-Way ANOVA

Description

Contains the job satisfaction score organized by gender and education level.

It is the data set used in the Datanovia tutorial “Two-Way ANOVA in R: Two Factors and Their Interaction” (https://www.datanovia.com/learn/biostatistics/anova/two-way-anova-in-r).

Usage

data("jobsatisfaction")

Arguments

Format

A data frame with 58 rows and 4 columns (stored as a tibble).

id

participant identifier (1 to 58).

gender

the participant's gender, "male" or "female".

education_level

the participant's education level, "school", "college" or "university".

score

a simulated job satisfaction score (an arbitrary scale with no real-world units).

See Also

Examples

Run this code
data(jobsatisfaction)
head(jobsatisfaction)

# Two-way ANOVA of satisfaction by gender and education level
summary(aov(score ~ gender * education_level, data = jobsatisfaction))

Run the code above in your browser using DataLab