powered by
Contains the job satisfaction score organized by gender and education level.
It is the data set used in the Datanovia tutorial “Two-Way ANOVA in R: Two Factors and Their Interaction” (https://www.datanovia.com/learn/biostatistics/anova/two-way-anova-in-r).
data("jobsatisfaction")
A data frame with 58 rows and 4 columns (stored as a tibble).
participant identifier (1 to 58).
the participant's gender, "male" or "female".
the participant's education level, "school", "college" or "university".
a simulated job satisfaction score (an arbitrary scale with no real-world units).
Datanovia tutorial: Two-Way ANOVA in R: Two Factors and Their Interaction.
data(jobsatisfaction) head(jobsatisfaction) # Two-way ANOVA of satisfaction by gender and education level summary(aov(score ~ gender * education_level, data = jobsatisfaction))
Run the code above in your browser using DataLab