powered by
Contains the weight of 10 mice. The question is whether the average weight of the mice differs from 25g.
A one sample t-test can be performed to answer to this question.
It is the data set used in the Datanovia tutorial “T-Test in R: One-Sample, Independent (Student & Welch) & Paired” (https://www.datanovia.com/learn/biostatistics/two-groups/t-test-in-r).
data("mice")
A data frame with 10 rows and 2 columns (stored as a tibble).
mouse identifier, "M_1" to "M_10".
the mouse weight, in grams.
mice2, the paired-samples companion data set. Datanovia tutorial: T-Test in R: One-Sample, Independent (Student & Welch) & Paired.
mice2
data(mice) head(mice) # One-sample t-test: does the mean weight differ from 25 g? t.test(mice$weight, mu = 25)
Run the code above in your browser using DataLab