powered by
contains the weight of 10 mice before and after the treatment.
A paired-samples t-test can be performed to answer to this question.
It is the data set used in the Datanovia tutorial “T-Test in R: One-Sample, Independent (Student & Welch) & Paired” (https://www.datanovia.com/learn/biostatistics/two-groups/t-test-in-r).
data("mice2")
A data frame with 10 rows and 3 columns.
mouse identifier (1 to 10).
the mouse weight before the treatment.
the mouse weight after the treatment.
mice, the one-sample companion data set. Datanovia tutorial: T-Test in R: One-Sample, Independent (Student & Welch) & Paired.
mice
data(mice2) head(mice2) # Paired-samples t-test: did the treatment change the weight? t.test(mice2$before, mice2$after, paired = TRUE)
Run the code above in your browser using DataLab