Contains the type of properties and the buyer types. Buyer
categories are: "single male", "single female", "married couple" and
"family".
The type of property these buyers purchased were sorted into four
categories: "flat", "bungalow" (i.e., a one-storey home), "detached house"
and "terrace" (i.e., a block of adjoining houses).
Chi-square test of independence can be used to assess the association between
the type of buyer who purchases a property and the type of property that is
purchased.
For a worked tutorial on this analysis, see the Datanovia lesson
“Chi-Square Test of Independence in R: Are Two Variables Associated?”
(https://www.datanovia.com/learn/biostatistics/categorical/chi-square-test-of-independence-in-r).