Learn R Programming

datarium (version 0.2.0)

titanic.raw: Survival of Passengers on the Titanic

Description

Survival of passengers on the Titanic. This data set provides information on the fate of passengers on the fatal maiden voyage of the ocean liner "Titanic". Columns are economic status (Class), Sex, Age and Survived.

It is the data set used in the Datanovia tutorial “Descriptive Statistics for Categorical Data in R: Contingency Tables” (https://www.datanovia.com/learn/biostatistics/categorical/categorical-descriptive-statistics-in-r).

Usage

data("titanic.raw")

Arguments

Format

A data frame with 2201 rows and 4 columns.

Class

the passenger's economic status, "1st", "2nd", "3rd" or "Crew".

Sex

the passenger's sex, "Male" or "Female".

Age

the age category, "Child" or "Adult".

Survived

whether the passenger survived, "No" or "Yes".

See Also

Examples

Run this code
data(titanic.raw)
with(titanic.raw, table(Class, Survived))

Run the code above in your browser using DataLab